@@ -6,9 +6,8 @@
 .onAttach <- function(libname, pkgname) {
     if (!.pkgenv$has_data) {
         msg <- paste("To produce graphics for the package vignettes, you must install the",
-                     "ArchaeoPhases.dataset package. To install that ",
-                     "package, run `install.packages('ArchaeoPhases.dataset',",
-                     "repos='https://tsdye.github.io/drat/', type='source')`.")
+                     "ArchaeoPhases.dataset packagef from CRAN. To install that ",
+                     "package, run `install.packages('ArchaeoPhases.dataset')`.")
         msg <- paste(strwrap(msg), collapse="\n")
         packageStartupMessage(msg)
     }
